pub struct RpcRequestClient {
client: Client,
rpc_address: SocketAddr,
}Expand description
An HTTP client for making JSON-RPC requests.
Fields
client: Clientrpc_address: SocketAddrImplementations
Sourceimpl RpcRequestClient
impl RpcRequestClient
Sourcepub fn new(rpc_address: SocketAddr) -> Self
pub fn new(rpc_address: SocketAddr) -> Self
Creates new RPCRequestSender
Sourcepub async fn call(
&self,
method: impl AsRef<str>,
params: impl AsRef<str>,
) -> Result<Response>
pub async fn call( &self, method: impl AsRef<str>, params: impl AsRef<str>, ) -> Result<Response>
Builds rpc request
Sourcepub async fn call_with_content_type(
&self,
method: impl AsRef<str>,
params: impl AsRef<str>,
content_type: String,
) -> Result<Response>
pub async fn call_with_content_type( &self, method: impl AsRef<str>, params: impl AsRef<str>, content_type: String, ) -> Result<Response>
Builds rpc request with a variable content-type.
Sourcepub async fn call_with_no_content_type(
&self,
method: impl AsRef<str>,
params: impl AsRef<str>,
) -> Result<Response>
pub async fn call_with_no_content_type( &self, method: impl AsRef<str>, params: impl AsRef<str>, ) -> Result<Response>
Builds rpc request with no content type.
Sourcepub async fn text_from_call(
&self,
method: impl AsRef<str>,
params: impl AsRef<str>,
) -> Result<String>
pub async fn text_from_call( &self, method: impl AsRef<str>, params: impl AsRef<str>, ) -> Result<String>
Builds rpc request and gets text from response
Sourcepub async fn json_result_from_call<T: DeserializeOwned>(
&self,
method: impl AsRef<str>,
params: impl AsRef<str>,
) -> Result<T, BoxError>
pub async fn json_result_from_call<T: DeserializeOwned>( &self, method: impl AsRef<str>, params: impl AsRef<str>, ) -> Result<T, BoxError>
Builds an RPC request, awaits its response, and attempts to deserialize it to the expected result type.
Returns Ok with json result from response if successful. Returns an error if the call or result deserialization fail.
Sourcefn json_result_from_response_text<T: DeserializeOwned>(
response_text: &str,
) -> Result<T, BoxError>
fn json_result_from_response_text<T: DeserializeOwned>( response_text: &str, ) -> Result<T, BoxError>
Accepts response text from an RPC call
Returns Ok with a deserialized result value in the expected type, or an error report.